"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ElasticsearchCatHealth = void 0;
var _error = require("@webiny/error");
var _stripConnectionFromException = require("./stripConnectionFromException");
class ElasticsearchCatHealth {
  constructor(client) {
    this.client = client;
  }
  async getHealth() {
    try {
      const response = await this.client.cat.health({
        format: "json"
      });
      if (!Array.isArray(response.body) || response.body.length === 0) {
        throw new _error.WebinyError({
          message: `There is no valid response from cat.health operation.`,
          code: "ELASTICSEARCH_HEALTH_INVALID_RESPONSE",
          data: response.body
        });
      }
      return {
        ...response.body[0]
      };
    } catch (ex) {
      console.error(`Could not fetch cluster health information: ${ex.message}`);
      const error = (0, _stripConnectionFromException.stripConnectionFromException)(ex);
      console.log(JSON.stringify(error));
      throw error;
    }
  }
}
exports.ElasticsearchCatHealth = ElasticsearchCatHealth;

//# sourceMappingURL=ElasticsearchCatHealth.js.map