import { Client } from "../../client";
import { ElasticsearchCatClusterHealthStatus } from "../../operations/types";
import { ClusterHealthReason, MemoryReason, ProcessorReason } from "./reason";
export type WaitingReason = ProcessorReason | MemoryReason | ClusterHealthReason;
export interface IWaitUntilHealthyParams {
    /**
     * Minimum status allowed, otherwise the cluster is considered unhealthy.
     */
    minClusterHealthStatus: ElasticsearchCatClusterHealthStatus.Green | ElasticsearchCatClusterHealthStatus.Yellow;
    /**
     * Maximum processor percent allowed, otherwise the cluster is considered unhealthy.
     */
    maxProcessorPercent: number;
    /**
     * Maximum RAM percent allowed, otherwise the cluster is considered unhealthy.
     */
    maxRamPercent?: number;
    /**
     * Maximum time to wait in seconds.
     * This is to prevent infinite waiting in case the cluster never becomes healthy.
     */
    maxWaitingTime: number;
    /**
     * Time in seconds to wait between each check.
     * This is to prevent spamming the cluster with requests.
     * Default is WAITING_TIME_STEP seconds.
     */
    waitingTimeStep?: number;
}
export interface IWaitOptionsOnUnhealthyParams {
    startedAt: Date;
    mustEndAt: Date;
    waitingTimeStep: number;
    runs: number;
    waitingReason: WaitingReason;
}
export interface IWaitOptionsOnTimeoutParams {
    startedAt: Date;
    mustEndAt: Date;
    waitingTimeStep: number;
    runs: number;
    waitingReason: WaitingReason;
}
export interface IWaitOptions {
    onUnhealthy?(params: IWaitOptionsOnUnhealthyParams): Promise<void>;
    onTimeout?(params: IWaitOptionsOnTimeoutParams): Promise<void>;
}
export interface IWaitUntilHealthyWaitResponse {
    runningTime: number;
    runs: number;
}
declare class WaitUntilHealthy {
    private readonly client;
    private readonly options;
    private readonly catHealth;
    private readonly catNodes;
    private aborted;
    constructor(client: Client, options: IWaitUntilHealthyParams);
    abort(): void;
    /**
     * @throws UnhealthyClusterError
     * @throws WaitingHealthyClusterAbortedError
     */
    wait(options?: IWaitOptions): Promise<IWaitUntilHealthyWaitResponse>;
    private shouldWait;
    private getProcessorPercent;
    private getRamPercent;
    private transformClusterHealthStatus;
}
export type { WaitUntilHealthy };
export declare const createWaitUntilHealthy: (client: Client, params: IWaitUntilHealthyParams) => WaitUntilHealthy;
